// python wrapper for vtkGeoTreeNodeCache
//
#define VTK_WRAPPING_CXX
#define VTK_STREAMS_FWD_ONLY
#include "vtkPythonArgs.h"
#include "vtkPythonOverload.h"
#include "vtkConfigure.h"
#include <cstddef>
#include <sstream>
#include "vtkVariant.h"
#include "vtkIndent.h"
#include "vtkGeoTreeNodeCache.h"

extern "C" { VTK_ABI_EXPORT void PyVTKAddFile_vtkGeoTreeNodeCache(PyObject *); }
extern "C" { VTK_ABI_EXPORT PyObject *PyvtkGeoTreeNodeCache_ClassNew(); }

#ifndef DECLARED_PyvtkObject_ClassNew
extern "C" { PyObject *PyvtkObject_ClassNew(); }
#define DECLARED_PyvtkObject_ClassNew
#endif

static const char *PyvtkGeoTreeNodeCache_Doc =
  "vtkGeoTreeNodeCache - Manages a list of vtkGeoTreeNodes.\n\n"
  "Superclass: vtkObject\n\n"
  "vtkGeoTreeNodeCache keeps track of a linked list of vtkGeoTreeNodes,\n"
  "and has operations to move nodes to the front of the list and to\n"
  "delete data from the least used nodes. This is used to recover memory\n"
  "from nodes that store data that hasn't been used in a while.\n\n";


static PyObject *
PyvtkGeoTreeNodeCache_IsTypeOf(PyObject *, PyObject *args)
{
  vtkPythonArgs ap(args, "IsTypeOf");

  const char *temp0 = nullptr;
  PyObject *result = nullptr;

  if (ap.CheckArgCount(1) &&
      ap.GetValue(temp0))
  {
    int tempr = vtkGeoTreeNodeCache::IsTypeOf(temp0);

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkGeoTreeNodeCache_IsA(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "IsA");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkGeoTreeNodeCache *op = static_cast<vtkGeoTreeNodeCache *>(vp);

  const char *temp0 = nullptr;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(1) &&
      ap.GetValue(temp0))
  {
    int tempr = (ap.IsBound() ?
      op->IsA(temp0) :
      op->vtkGeoTreeNodeCache::IsA(temp0));

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkGeoTreeNodeCache_SafeDownCast(PyObject *, PyObject *args)
{
  vtkPythonArgs ap(args, "SafeDownCast");

  vtkObjectBase *temp0 = nullptr;
  PyObject *result = nullptr;

  if (ap.CheckArgCount(1) &&
      ap.GetVTKObject(temp0, "vtkObjectBase"))
  {
    vtkGeoTreeNodeCache *tempr = vtkGeoTreeNodeCache::SafeDownCast(temp0);

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildVTKObject(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkGeoTreeNodeCache_NewInstance(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "NewInstance");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkGeoTreeNodeCache *op = static_cast<vtkGeoTreeNodeCache *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    vtkGeoTreeNodeCache *tempr = (ap.IsBound() ?
      op->NewInstance() :
      op->vtkGeoTreeNodeCache::NewInstance());

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildVTKObject(tempr);
      if (result && PyVTKObject_Check(result))
      {
        PyVTKObject_GetObject(result)->UnRegister(0);
        PyVTKObject_SetFlag(result, VTK_PYTHON_IGNORE_UNREGISTER, 1);
      }
    }
  }

  return result;
}


static PyObject *
PyvtkGeoTreeNodeCache_SetCacheMaximumLimit(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "SetCacheMaximumLimit");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkGeoTreeNodeCache *op = static_cast<vtkGeoTreeNodeCache *>(vp);

  int temp0;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(1) &&
      ap.GetValue(temp0))
  {
    if (ap.IsBound())
    {
      op->SetCacheMaximumLimit(temp0);
    }
    else
    {
      op->vtkGeoTreeNodeCache::SetCacheMaximumLimit(temp0);
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}


static PyObject *
PyvtkGeoTreeNodeCache_GetCacheMaximumLimit(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "GetCacheMaximumLimit");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkGeoTreeNodeCache *op = static_cast<vtkGeoTreeNodeCache *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    int tempr = (ap.IsBound() ?
      op->GetCacheMaximumLimit() :
      op->vtkGeoTreeNodeCache::GetCacheMaximumLimit());

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkGeoTreeNodeCache_SetCacheMinimumLimit(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "SetCacheMinimumLimit");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkGeoTreeNodeCache *op = static_cast<vtkGeoTreeNodeCache *>(vp);

  int temp0;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(1) &&
      ap.GetValue(temp0))
  {
    if (ap.IsBound())
    {
      op->SetCacheMinimumLimit(temp0);
    }
    else
    {
      op->vtkGeoTreeNodeCache::SetCacheMinimumLimit(temp0);
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}


static PyObject *
PyvtkGeoTreeNodeCache_GetCacheMinimumLimit(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "GetCacheMinimumLimit");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkGeoTreeNodeCache *op = static_cast<vtkGeoTreeNodeCache *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    int tempr = (ap.IsBound() ?
      op->GetCacheMinimumLimit() :
      op->vtkGeoTreeNodeCache::GetCacheMinimumLimit());

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkGeoTreeNodeCache_SendToFront(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "SendToFront");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkGeoTreeNodeCache *op = static_cast<vtkGeoTreeNodeCache *>(vp);

  vtkGeoTreeNode *temp0 = nullptr;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(1) &&
      ap.GetVTKObject(temp0, "vtkGeoTreeNode"))
  {
    if (ap.IsBound())
    {
      op->SendToFront(temp0);
    }
    else
    {
      op->vtkGeoTreeNodeCache::SendToFront(temp0);
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}


static PyObject *
PyvtkGeoTreeNodeCache_RemoveNode(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "RemoveNode");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkGeoTreeNodeCache *op = static_cast<vtkGeoTreeNodeCache *>(vp);

  vtkGeoTreeNode *temp0 = nullptr;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(1) &&
      ap.GetVTKObject(temp0, "vtkGeoTreeNode"))
  {
    if (ap.IsBound())
    {
      op->RemoveNode(temp0);
    }
    else
    {
      op->vtkGeoTreeNodeCache::RemoveNode(temp0);
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}


static PyObject *
PyvtkGeoTreeNodeCache_GetSize(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "GetSize");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkGeoTreeNodeCache *op = static_cast<vtkGeoTreeNodeCache *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    int tempr = (ap.IsBound() ?
      op->GetSize() :
      op->vtkGeoTreeNodeCache::GetSize());

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}

static PyMethodDef PyvtkGeoTreeNodeCache_Methods[] = {
  {"IsTypeOf", PyvtkGeoTreeNodeCache_IsTypeOf, METH_VARARGS,
   "V.IsTypeOf(string) -> int\nC++: static vtkTypeBool IsTypeOf(const char *type)\n\nReturn 1 if this class type is the same type of (or a subclass\nof) the named class. Returns 0 otherwise. This method works in\ncombination with vtkTypeMacro found in vtkSetGet.h.\n"},
  {"IsA", PyvtkGeoTreeNodeCache_IsA, METH_VARARGS,
   "V.IsA(string) -> int\nC++: vtkTypeBool IsA(const char *type) override;\n\nReturn 1 if this class is the same type of (or a subclass of) the\nnamed class. Returns 0 otherwise. This method works in\ncombination with vtkTypeMacro found in vtkSetGet.h.\n"},
  {"SafeDownCast", PyvtkGeoTreeNodeCache_SafeDownCast, METH_VARARGS,
   "V.SafeDownCast(vtkObjectBase) -> vtkGeoTreeNodeCache\nC++: static vtkGeoTreeNodeCache *SafeDownCast(vtkObjectBase *o)\n\n"},
  {"NewInstance", PyvtkGeoTreeNodeCache_NewInstance, METH_VARARGS,
   "V.NewInstance() -> vtkGeoTreeNodeCache\nC++: vtkGeoTreeNodeCache *NewInstance()\n\n"},
  {"SetCacheMaximumLimit", PyvtkGeoTreeNodeCache_SetCacheMaximumLimit, METH_VARARGS,
   "V.SetCacheMaximumLimit(int)\nC++: virtual void SetCacheMaximumLimit(int _arg)\n\nThe size of the cache of geospatial nodes. When the size reaches\nthis limit, the list of non-empty nodes will be shortened to\nCacheMinimumLimit.\n"},
  {"GetCacheMaximumLimit", PyvtkGeoTreeNodeCache_GetCacheMaximumLimit, METH_VARARGS,
   "V.GetCacheMaximumLimit() -> int\nC++: virtual int GetCacheMaximumLimit()\n\nThe size of the cache of geospatial nodes. When the size reaches\nthis limit, the list of non-empty nodes will be shortened to\nCacheMinimumLimit.\n"},
  {"SetCacheMinimumLimit", PyvtkGeoTreeNodeCache_SetCacheMinimumLimit, METH_VARARGS,
   "V.SetCacheMinimumLimit(int)\nC++: virtual void SetCacheMinimumLimit(int _arg)\n\nThe cache is reduced to this size when the maximum limit is\nreached.\n"},
  {"GetCacheMinimumLimit", PyvtkGeoTreeNodeCache_GetCacheMinimumLimit, METH_VARARGS,
   "V.GetCacheMinimumLimit() -> int\nC++: virtual int GetCacheMinimumLimit()\n\nThe cache is reduced to this size when the maximum limit is\nreached.\n"},
  {"SendToFront", PyvtkGeoTreeNodeCache_SendToFront, METH_VARARGS,
   "V.SendToFront(vtkGeoTreeNode)\nC++: void SendToFront(vtkGeoTreeNode *node)\n\nSend a node to the front of the list. Perform this whenever a\nnode is accessed, so that the most recently accessed nodes' data\nare not deleted.\n"},
  {"RemoveNode", PyvtkGeoTreeNodeCache_RemoveNode, METH_VARARGS,
   "V.RemoveNode(vtkGeoTreeNode)\nC++: void RemoveNode(vtkGeoTreeNode *node)\n\nRemove the node from the list.\n"},
  {"GetSize", PyvtkGeoTreeNodeCache_GetSize, METH_VARARGS,
   "V.GetSize() -> int\nC++: virtual int GetSize()\n\nThe current size of the list.\n"},
  {nullptr, nullptr, 0, nullptr}
};

static PyTypeObject PyvtkGeoTreeNodeCache_Type = {
  PyVarObject_HEAD_INIT(&PyType_Type, 0)
  "vtkGeovisCorePython.vtkGeoTreeNodeCache", // tp_name
  sizeof(PyVTKObject), // tp_basicsize
  0, // tp_itemsize
  PyVTKObject_Delete, // tp_dealloc
  0, // tp_vectorcall_offset
  nullptr, // tp_getattr
  nullptr, // tp_setattr
  nullptr, // tp_compare
  PyVTKObject_Repr, // tp_repr
  nullptr, // tp_as_number
  nullptr, // tp_as_sequence
  nullptr, // tp_as_mapping
  nullptr, // tp_hash
  nullptr, // tp_call
  PyVTKObject_String, // tp_str
  PyObject_GenericGetAttr, // tp_getattro
  PyObject_GenericSetAttr, // tp_setattro
  &PyVTKObject_AsBuffer, // tp_as_buffer
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_BASETYPE, // tp_flags
  PyvtkGeoTreeNodeCache_Doc, // tp_doc
  PyVTKObject_Traverse, // tp_traverse
  nullptr, // tp_clear
  nullptr, // tp_richcompare
  offsetof(PyVTKObject, vtk_weakreflist), // tp_weaklistoffset
  nullptr, // tp_iter
  nullptr, // tp_iternext
  nullptr, // tp_methods
  nullptr, // tp_members
  PyVTKObject_GetSet, // tp_getset
  nullptr, // tp_base
  nullptr, // tp_dict
  nullptr, // tp_descr_get
  nullptr, // tp_descr_set
  offsetof(PyVTKObject, vtk_dict), // tp_dictoffset
  nullptr, // tp_init
  nullptr, // tp_alloc
  PyVTKObject_New, // tp_new
  PyObject_GC_Del, // tp_free
  nullptr, // tp_is_gc
  nullptr, // tp_bases
  nullptr, // tp_mro
  nullptr, // tp_cache
  nullptr, // tp_subclasses
  nullptr, // tp_weaklist
  VTK_WRAP_PYTHON_SUPPRESS_UNINITIALIZED
};

static vtkObjectBase *PyvtkGeoTreeNodeCache_StaticNew()
{
  return vtkGeoTreeNodeCache::New();
}

PyObject *PyvtkGeoTreeNodeCache_ClassNew()
{
  PyVTKClass_Add(
    &PyvtkGeoTreeNodeCache_Type, PyvtkGeoTreeNodeCache_Methods,
    "vtkGeoTreeNodeCache",
 &PyvtkGeoTreeNodeCache_StaticNew);

  PyTypeObject *pytype = &PyvtkGeoTreeNodeCache_Type;

  if ((pytype->tp_flags & Py_TPFLAGS_READY) != 0)
  {
    return (PyObject *)pytype;
  }

#if !defined(VTK_PY3K) && PY_VERSION_HEX >= 0x02060000
  pytype->tp_flags |= Py_TPFLAGS_HAVE_NEWBUFFER;
#endif

  pytype->tp_base = (PyTypeObject *)PyvtkObject_ClassNew();

  PyType_Ready(pytype);
  return (PyObject *)pytype;
}

void PyVTKAddFile_vtkGeoTreeNodeCache(
  PyObject *dict)
{
  PyObject *o;
  o = PyvtkGeoTreeNodeCache_ClassNew();

  if (o && PyDict_SetItemString(dict, "vtkGeoTreeNodeCache", o) != 0)
  {
    Py_DECREF(o);
  }

}

