// python wrapper for vtkGeoView
//
#define VTK_WRAPPING_CXX
#define VTK_STREAMS_FWD_ONLY
#include "vtkPythonArgs.h"
#include "vtkPythonOverload.h"
#include "vtkConfigure.h"
#include <cstddef>
#include <sstream>
#include "vtkVariant.h"
#include "vtkIndent.h"
#include "vtkGeoView.h"

extern "C" { VTK_ABI_EXPORT void PyVTKAddFile_vtkGeoView(PyObject *); }
extern "C" { VTK_ABI_EXPORT PyObject *PyvtkGeoView_ClassNew(); }

#ifndef DECLARED_PyvtkRenderView_ClassNew
extern "C" { PyObject *PyvtkRenderView_ClassNew(); }
#define DECLARED_PyvtkRenderView_ClassNew
#endif

static const char *PyvtkGeoView_Doc =
  "vtkGeoView - A 3D geospatial view.\n\n"
  "Superclass: vtkRenderView\n\n"
  "vtkGeoView is a 3D globe view. The globe may contain a\n"
  "multi-resolution geometry source (vtkGeoTerrain), multiple\n"
  "multi-resolution image sources (vtkGeoAlignedImageRepresentation), as\n"
  "well as other representations such as vtkRenderedGraphRepresentation.\n"
  "At a minimum, the view must have a terrain and one image\n"
  "representation. The view uses vtkGeoInteractorStyle to orbit, zoom,\n"
  "and tilt the view, and contains a vtkCompassWidget for manipulating\n"
  "the camera.\n\n"
  "Each terrain or image representation contains a vtkGeoSource subclass\n"
  "which generates geometry or imagery at multiple resolutions. As the\n"
  "camera position changes, the terrain and/or image representations may\n"
  "ask its vtkGeoSource to refine the geometry. This refinement is\n"
  "performed on a separate thread, and the data is added to the view\n"
  "when it becomes available.\n\n"
  "@sa\n"
  "vtkGeoTerrain vtkGeoAlignedImageRepresentation vtkGeoSource\n\n";


static PyObject *
PyvtkGeoView_IsTypeOf(PyObject *, PyObject *args)
{
  vtkPythonArgs ap(args, "IsTypeOf");

  const char *temp0 = nullptr;
  PyObject *result = nullptr;

  if (ap.CheckArgCount(1) &&
      ap.GetValue(temp0))
  {
    int tempr = vtkGeoView::IsTypeOf(temp0);

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkGeoView_IsA(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "IsA");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkGeoView *op = static_cast<vtkGeoView *>(vp);

  const char *temp0 = nullptr;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(1) &&
      ap.GetValue(temp0))
  {
    int tempr = (ap.IsBound() ?
      op->IsA(temp0) :
      op->vtkGeoView::IsA(temp0));

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkGeoView_SafeDownCast(PyObject *, PyObject *args)
{
  vtkPythonArgs ap(args, "SafeDownCast");

  vtkObjectBase *temp0 = nullptr;
  PyObject *result = nullptr;

  if (ap.CheckArgCount(1) &&
      ap.GetVTKObject(temp0, "vtkObjectBase"))
  {
    vtkGeoView *tempr = vtkGeoView::SafeDownCast(temp0);

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildVTKObject(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkGeoView_NewInstance(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "NewInstance");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkGeoView *op = static_cast<vtkGeoView *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    vtkGeoView *tempr = (ap.IsBound() ?
      op->NewInstance() :
      op->vtkGeoView::NewInstance());

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildVTKObject(tempr);
      if (result && PyVTKObject_Check(result))
      {
        PyVTKObject_GetObject(result)->UnRegister(0);
        PyVTKObject_SetFlag(result, VTK_PYTHON_IGNORE_UNREGISTER, 1);
      }
    }
  }

  return result;
}


static PyObject *
PyvtkGeoView_AddDefaultImageRepresentation(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "AddDefaultImageRepresentation");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkGeoView *op = static_cast<vtkGeoView *>(vp);

  vtkImageData *temp0 = nullptr;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(1) &&
      ap.GetVTKObject(temp0, "vtkImageData"))
  {
    vtkGeoAlignedImageRepresentation *tempr = (ap.IsBound() ?
      op->AddDefaultImageRepresentation(temp0) :
      op->vtkGeoView::AddDefaultImageRepresentation(temp0));

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildVTKObject(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkGeoView_PrepareForRendering(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "PrepareForRendering");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkGeoView *op = static_cast<vtkGeoView *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    if (ap.IsBound())
    {
      op->PrepareForRendering();
    }
    else
    {
      op->vtkGeoView::PrepareForRendering();
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}


static PyObject *
PyvtkGeoView_BuildLowResEarth(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "BuildLowResEarth");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkGeoView *op = static_cast<vtkGeoView *>(vp);

  const size_t size0 = 3;
  double temp0[3];
  double save0[3];
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(1) &&
      ap.GetArray(temp0, size0))
  {
    ap.Save(temp0, save0, size0);

    if (ap.IsBound())
    {
      op->BuildLowResEarth(temp0);
    }
    else
    {
      op->vtkGeoView::BuildLowResEarth(temp0);
    }

    if (ap.HasChanged(temp0, save0, size0) &&
        !ap.ErrorOccurred())
    {
      ap.SetArray(0, temp0, size0);
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}


static PyObject *
PyvtkGeoView_SetLockHeading(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "SetLockHeading");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkGeoView *op = static_cast<vtkGeoView *>(vp);

  bool temp0 = false;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(1) &&
      ap.GetValue(temp0))
  {
    if (ap.IsBound())
    {
      op->SetLockHeading(temp0);
    }
    else
    {
      op->vtkGeoView::SetLockHeading(temp0);
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}


static PyObject *
PyvtkGeoView_GetLockHeading(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "GetLockHeading");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkGeoView *op = static_cast<vtkGeoView *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    bool tempr = (ap.IsBound() ?
      op->GetLockHeading() :
      op->vtkGeoView::GetLockHeading());

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkGeoView_LockHeadingOn(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "LockHeadingOn");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkGeoView *op = static_cast<vtkGeoView *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    if (ap.IsBound())
    {
      op->LockHeadingOn();
    }
    else
    {
      op->vtkGeoView::LockHeadingOn();
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}


static PyObject *
PyvtkGeoView_LockHeadingOff(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "LockHeadingOff");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkGeoView *op = static_cast<vtkGeoView *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    if (ap.IsBound())
    {
      op->LockHeadingOff();
    }
    else
    {
      op->vtkGeoView::LockHeadingOff();
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}


static PyObject *
PyvtkGeoView_GetGeoInteractorStyle(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "GetGeoInteractorStyle");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkGeoView *op = static_cast<vtkGeoView *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    vtkGeoInteractorStyle *tempr = (ap.IsBound() ?
      op->GetGeoInteractorStyle() :
      op->vtkGeoView::GetGeoInteractorStyle());

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildVTKObject(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkGeoView_SetGeoInteractorStyle(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "SetGeoInteractorStyle");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkGeoView *op = static_cast<vtkGeoView *>(vp);

  vtkGeoInteractorStyle *temp0 = nullptr;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(1) &&
      ap.GetVTKObject(temp0, "vtkGeoInteractorStyle"))
  {
    if (ap.IsBound())
    {
      op->SetGeoInteractorStyle(temp0);
    }
    else
    {
      op->vtkGeoView::SetGeoInteractorStyle(temp0);
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}


static PyObject *
PyvtkGeoView_SetTerrain(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "SetTerrain");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkGeoView *op = static_cast<vtkGeoView *>(vp);

  vtkGeoTerrain *temp0 = nullptr;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(1) &&
      ap.GetVTKObject(temp0, "vtkGeoTerrain"))
  {
    if (ap.IsBound())
    {
      op->SetTerrain(temp0);
    }
    else
    {
      op->vtkGeoView::SetTerrain(temp0);
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}


static PyObject *
PyvtkGeoView_GetTerrain(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "GetTerrain");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkGeoView *op = static_cast<vtkGeoView *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    vtkGeoTerrain *tempr = (ap.IsBound() ?
      op->GetTerrain() :
      op->vtkGeoView::GetTerrain());

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildVTKObject(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkGeoView_Render(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "Render");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkGeoView *op = static_cast<vtkGeoView *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    if (ap.IsBound())
    {
      op->Render();
    }
    else
    {
      op->vtkGeoView::Render();
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}

static PyMethodDef PyvtkGeoView_Methods[] = {
  {"IsTypeOf", PyvtkGeoView_IsTypeOf, METH_VARARGS,
   "V.IsTypeOf(string) -> int\nC++: static vtkTypeBool IsTypeOf(const char *type)\n\nReturn 1 if this class type is the same type of (or a subclass\nof) the named class. Returns 0 otherwise. This method works in\ncombination with vtkTypeMacro found in vtkSetGet.h.\n"},
  {"IsA", PyvtkGeoView_IsA, METH_VARARGS,
   "V.IsA(string) -> int\nC++: vtkTypeBool IsA(const char *type) override;\n\nReturn 1 if this class is the same type of (or a subclass of) the\nnamed class. Returns 0 otherwise. This method works in\ncombination with vtkTypeMacro found in vtkSetGet.h.\n"},
  {"SafeDownCast", PyvtkGeoView_SafeDownCast, METH_VARARGS,
   "V.SafeDownCast(vtkObjectBase) -> vtkGeoView\nC++: static vtkGeoView *SafeDownCast(vtkObjectBase *o)\n\n"},
  {"NewInstance", PyvtkGeoView_NewInstance, METH_VARARGS,
   "V.NewInstance() -> vtkGeoView\nC++: vtkGeoView *NewInstance()\n\n"},
  {"AddDefaultImageRepresentation", PyvtkGeoView_AddDefaultImageRepresentation, METH_VARARGS,
   "V.AddDefaultImageRepresentation(vtkImageData)\n    -> vtkGeoAlignedImageRepresentation\nC++: vtkGeoAlignedImageRepresentation *AddDefaultImageRepresentation(\n    vtkImageData *image)\n\nAdds an image representation with a simple terrain model using\nthe image in the specified file as the globe terrain.\n"},
  {"PrepareForRendering", PyvtkGeoView_PrepareForRendering, METH_VARARGS,
   "V.PrepareForRendering()\nC++: void PrepareForRendering() override;\n\nPrepares the view for rendering.\n"},
  {"BuildLowResEarth", PyvtkGeoView_BuildLowResEarth, METH_VARARGS,
   "V.BuildLowResEarth([float, float, float])\nC++: void BuildLowResEarth(double origin[3])\n\nRebuild low-res earth source; call after (re)setting origin.\n"},
  {"SetLockHeading", PyvtkGeoView_SetLockHeading, METH_VARARGS,
   "V.SetLockHeading(bool)\nC++: virtual void SetLockHeading(bool lock)\n\nWhether the view locks the heading when panning. Default is off.\n"},
  {"GetLockHeading", PyvtkGeoView_GetLockHeading, METH_VARARGS,
   "V.GetLockHeading() -> bool\nC++: virtual bool GetLockHeading()\n\nWhether the view locks the heading when panning. Default is off.\n"},
  {"LockHeadingOn", PyvtkGeoView_LockHeadingOn, METH_VARARGS,
   "V.LockHeadingOn()\nC++: virtual void LockHeadingOn()\n\nWhether the view locks the heading when panning. Default is off.\n"},
  {"LockHeadingOff", PyvtkGeoView_LockHeadingOff, METH_VARARGS,
   "V.LockHeadingOff()\nC++: virtual void LockHeadingOff()\n\nWhether the view locks the heading when panning. Default is off.\n"},
  {"GetGeoInteractorStyle", PyvtkGeoView_GetGeoInteractorStyle, METH_VARARGS,
   "V.GetGeoInteractorStyle() -> vtkGeoInteractorStyle\nC++: vtkGeoInteractorStyle *GetGeoInteractorStyle()\n\nConvenience method for obtaining the internal interactor style.\n"},
  {"SetGeoInteractorStyle", PyvtkGeoView_SetGeoInteractorStyle, METH_VARARGS,
   "V.SetGeoInteractorStyle(vtkGeoInteractorStyle)\nC++: virtual void SetGeoInteractorStyle(\n    vtkGeoInteractorStyle *style)\n\nMethod to change the interactor style.\n"},
  {"SetTerrain", PyvtkGeoView_SetTerrain, METH_VARARGS,
   "V.SetTerrain(vtkGeoTerrain)\nC++: virtual void SetTerrain(vtkGeoTerrain *terrain)\n\nThe terrain (geometry) model for this earth view.\n"},
  {"GetTerrain", PyvtkGeoView_GetTerrain, METH_VARARGS,
   "V.GetTerrain() -> vtkGeoTerrain\nC++: virtual vtkGeoTerrain *GetTerrain()\n\nThe terrain (geometry) model for this earth view.\n"},
  {"Render", PyvtkGeoView_Render, METH_VARARGS,
   "V.Render()\nC++: void Render() override;\n\nUpdate and render the view.\n"},
  {nullptr, nullptr, 0, nullptr}
};

static PyTypeObject PyvtkGeoView_Type = {
  PyVarObject_HEAD_INIT(&PyType_Type, 0)
  "vtkViewsGeovisPython.vtkGeoView", // tp_name
  sizeof(PyVTKObject), // tp_basicsize
  0, // tp_itemsize
  PyVTKObject_Delete, // tp_dealloc
  0, // tp_vectorcall_offset
  nullptr, // tp_getattr
  nullptr, // tp_setattr
  nullptr, // tp_compare
  PyVTKObject_Repr, // tp_repr
  nullptr, // tp_as_number
  nullptr, // tp_as_sequence
  nullptr, // tp_as_mapping
  nullptr, // tp_hash
  nullptr, // tp_call
  PyVTKObject_String, // tp_str
  PyObject_GenericGetAttr, // tp_getattro
  PyObject_GenericSetAttr, // tp_setattro
  &PyVTKObject_AsBuffer, // tp_as_buffer
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_BASETYPE, // tp_flags
  PyvtkGeoView_Doc, // tp_doc
  PyVTKObject_Traverse, // tp_traverse
  nullptr, // tp_clear
  nullptr, // tp_richcompare
  offsetof(PyVTKObject, vtk_weakreflist), // tp_weaklistoffset
  nullptr, // tp_iter
  nullptr, // tp_iternext
  nullptr, // tp_methods
  nullptr, // tp_members
  PyVTKObject_GetSet, // tp_getset
  nullptr, // tp_base
  nullptr, // tp_dict
  nullptr, // tp_descr_get
  nullptr, // tp_descr_set
  offsetof(PyVTKObject, vtk_dict), // tp_dictoffset
  nullptr, // tp_init
  nullptr, // tp_alloc
  PyVTKObject_New, // tp_new
  PyObject_GC_Del, // tp_free
  nullptr, // tp_is_gc
  nullptr, // tp_bases
  nullptr, // tp_mro
  nullptr, // tp_cache
  nullptr, // tp_subclasses
  nullptr, // tp_weaklist
  VTK_WRAP_PYTHON_SUPPRESS_UNINITIALIZED
};

static vtkObjectBase *PyvtkGeoView_StaticNew()
{
  return vtkGeoView::New();
}

PyObject *PyvtkGeoView_ClassNew()
{
  PyVTKClass_Add(
    &PyvtkGeoView_Type, PyvtkGeoView_Methods,
    "vtkGeoView",
 &PyvtkGeoView_StaticNew);

  PyTypeObject *pytype = &PyvtkGeoView_Type;

  if ((pytype->tp_flags & Py_TPFLAGS_READY) != 0)
  {
    return (PyObject *)pytype;
  }

#if !defined(VTK_PY3K) && PY_VERSION_HEX >= 0x02060000
  pytype->tp_flags |= Py_TPFLAGS_HAVE_NEWBUFFER;
#endif

  pytype->tp_base = (PyTypeObject *)PyvtkRenderView_ClassNew();

  PyType_Ready(pytype);
  return (PyObject *)pytype;
}

void PyVTKAddFile_vtkGeoView(
  PyObject *dict)
{
  PyObject *o;
  o = PyvtkGeoView_ClassNew();

  if (o && PyDict_SetItemString(dict, "vtkGeoView", o) != 0)
  {
    Py_DECREF(o);
  }

}

